@@ -15,7 +15,11 @@ import yaml, argcomplete
 from .parser import get_parser, jq_arg_spec
 from .loader import get_loader
 from .dumper import get_dumper
-from .version import __version__  # noqa
+
+try:
+    from .version import version as __version__
+except ImportError:
+    __version__ = "0.0.0"
 
 class JSONDateTimeEncoder(json.JSONEncoder):
     def default(self, o):
@@ -133,6 +137,7 @@ def cli(args=None, input_format="yaml", program_name="yq"):
 
 def load_yaml_docs(in_stream, out_stream, jq, loader_class, max_expansion_factor, exit_func, prog):
     loader = loader_class(in_stream)
+
     last_loader_pos = 0
     try:
         while loader.check_node():
@@ -155,8 +160,8 @@ def load_yaml_docs(in_stream, out_stream, jq, loader_class, max_expansion_factor
 
 def yq(input_streams=None, output_stream=None, input_format="yaml", output_format="json",
        program_name="yq", width=None, indentless_lists=False, xml_root=None, xml_dtd=False, xml_force_list=frozenset(),
-       explicit_start=False, explicit_end=False, expand_aliases=True, max_expansion_factor=1024, jq_args=frozenset(),
-       exit_func=None):
+       explicit_start=False, explicit_end=False, expand_merge_keys=True, expand_aliases=True,
+       max_expansion_factor=1024, yaml_output_grammar_version="1.1", jq_args=frozenset(), exit_func=None):
     if not input_streams:
         input_streams = [sys.stdin]
     if not output_stream:
@@ -186,7 +191,8 @@ def yq(input_streams=None, output_stream=None, input_format="yaml", output_forma
             json_buffer = io.StringIO()
             for input_stream in input_streams:
                 if input_format == "yaml":
-                    loader_class = get_loader(use_annotations=use_annotations, expand_aliases=expand_aliases)
+                    loader_class = get_loader(use_annotations=use_annotations, expand_aliases=expand_aliases,
+                                              expand_merge_keys=expand_merge_keys)
                     load_yaml_docs(in_stream=input_stream, out_stream=json_buffer, jq=None, loader_class=loader_class,
                                    max_expansion_factor=max_expansion_factor, exit_func=exit_func, prog=program_name)
                 elif input_format == "xml":
@@ -204,7 +210,8 @@ def yq(input_streams=None, output_stream=None, input_format="yaml", output_forma
             jq_out, jq_err = jq.communicate(json_buffer.getvalue())
             json_decoder = json.JSONDecoder()
             if output_format == "yaml" or output_format == "annotated_yaml":
-                dumper_class = get_dumper(use_annotations=use_annotations, indentless=indentless_lists)
+                dumper_class = get_dumper(use_annotations=use_annotations, indentless=indentless_lists,
+                                          grammar_version=yaml_output_grammar_version)
                 yaml.dump_all(decode_docs(jq_out, json_decoder), stream=output_stream, Dumper=dumper_class,
                               width=width, allow_unicode=True, default_flow_style=False,
                               explicit_start=explicit_start, explicit_end=explicit_end)
@@ -236,7 +243,8 @@ def yq(input_streams=None, output_stream=None, input_format="yaml", output_forma
                     toml.dump(doc, output_stream)
         else:
             if input_format == "yaml":
-                loader_class = get_loader(use_annotations=False, expand_aliases=expand_aliases)
+                loader_class = get_loader(use_annotations=False, expand_aliases=expand_aliases,
+                                          expand_merge_keys=expand_merge_keys)
                 for input_stream in input_streams:
                     load_yaml_docs(in_stream=input_stream, out_stream=jq.stdin, jq=jq, loader_class=loader_class,
                                    max_expansion_factor=max_expansion_factor, exit_func=exit_func, prog=program_name)
